@@ -617,7 +617,9 @@ def _rename(context, old_path, new_path):
 
 @gen.coroutine
 def _copy_key(context, old_key, new_key):
-    yield _copy_object(context, context.s3_bucket, f'/{context.s3_bucket}/{old_key}', new_key)
+    # yield _copy_object(context, context.s3_bucket, f'/{context.s3_bucket}/{old_key}', new_key)
+
+    yield _copy_object(context, context.s3_bucket, old_key, new_key)
 
 
 @gen.coroutine
@@ -829,8 +831,8 @@ SAVERS = {
 def _head_object(context, bucket, key):
     credentials = yield context.s3_auth()
     s3_client = boto3.client('s3', aws_access_key_id=credentials.access_key_id,
-                             aws_secret_access_key=credentials.secret_access_key, region_name='us-east-1', endpoint_url="https://s3.amazonaws.com")
-    response = yield s3_client.list_objects_v2(
+                             aws_secret_access_key=credentials.secret_access_key, region_name='us-east-1', endpoint_url= context.endpoint_url)
+    response = s3_client.list_objects_v2(
         Bucket=bucket,
         Prefix=key,
         )
@@ -845,14 +847,14 @@ def _head_object(context, bucket, key):
 def _put_object(context, bucket, body, object_name):
     credentials = yield context.s3_auth()
     s3_client = boto3.client('s3', aws_access_key_id=credentials.access_key_id,
-                             aws_secret_access_key=credentials.secret_access_key, region_name='us-east-1', endpoint_url="https://s3.amazonaws.com")
+                             aws_secret_access_key=credentials.secret_access_key, region_name='us-east-1', endpoint_url= context.endpoint_url)
     return s3_client.put_object(Body=body, Bucket=bucket, Key=object_name)
 
 @gen.coroutine
 def _get_object(context, bucket, object_name):
     credentials = yield context.s3_auth()
     s3_client = boto3.client('s3', aws_access_key_id=credentials.access_key_id,
-                             aws_secret_access_key=credentials.secret_access_key, region_name='us-east-1', endpoint_url="https://s3.amazonaws.com")
+                             aws_secret_access_key=credentials.secret_access_key, region_name='us-east-1', endpoint_url= context.endpoint_url)
     return s3_client.get_object(Bucket=bucket, Key=object_name)
 
 @gen.coroutine
@@ -860,28 +862,41 @@ def _list_buckets(context):
     # Retrieve the list of existing buckets
     credentials = yield context.s3_auth()
     s3_client = boto3.client('s3', aws_access_key_id=credentials.access_key_id,
-                             aws_secret_access_key=credentials.secret_access_key, region_name='us-east-1', endpoint_url="https://s3.amazonaws.com")
+                             aws_secret_access_key=credentials.secret_access_key, region_name='us-east-1', endpoint_url = context.endpoint_url)
     return s3_client.list_buckets()
 
 @gen.coroutine
 def _copy_object(context, bucket, source_file, destination_file):
     credentials = yield context.s3_auth()
     s3_client = boto3.client('s3', aws_access_key_id=credentials.access_key_id,
-                             aws_secret_access_key=credentials.secret_access_key, region_name='us-east-1', endpoint_url="https://s3.amazonaws.com")
-    return s3_client.copy_object(Bucket=bucket, CopySource=source_file, Key=destination_file)
+                             aws_secret_access_key=credentials.secret_access_key, region_name='us-east-1', endpoint_url = context.endpoint_url)
+
+    response = yield _get_object(context, context.s3_bucket, source_file)
+    file_bytes = response['Body'].read()
+    response = yield _save_any(context, None, json.dumps(file_bytes).encode('utf-8'), _key(context, destination_file), 'notebook', None)
+    return response
+    # return s3_client.copy_object(Bucket=bucket, CopySource=source_file, Key=destination_file)
+
+# @gen.coroutine
+# def _copy_object(context, bucket, source_file, destination_file):
+#     credentials = yield context.s3_auth()
+#     s3_client = boto3.client('s3', aws_access_key_id=credentials.access_key_id,
+#                              aws_secret_access_key=credentials.secret_access_key, region_name='us-east-1', endpoint_url = context.endpoint_url)
+    
+#     return s3_client.copy_object(Bucket=bucket, CopySource=source_file, Key=destination_file)
 
 @gen.coroutine
 def _delete_object(context, bucket, file_name):
     credentials = yield context.s3_auth()
     s3_client = boto3.client('s3', aws_access_key_id=credentials.access_key_id,
-                             aws_secret_access_key=credentials.secret_access_key, region_name='us-east-1', endpoint_url="https://s3.amazonaws.com")
+                             aws_secret_access_key=credentials.secret_access_key, region_name='us-east-1', endpoint_url = context.endpoint_url)
     return s3_client.delete_object(Bucket=bucket, Key=file_name)
 
 @gen.coroutine
 def _list_objects(context, bucket, prefix, delimiter, max_keys, token=''):
     credentials = yield context.s3_auth()
     s3_client = boto3.client('s3', aws_access_key_id=credentials.access_key_id,
-                             aws_secret_access_key=credentials.secret_access_key, region_name='us-east-1', endpoint_url="https://s3.amazonaws.com")
+                             aws_secret_access_key=credentials.secret_access_key, region_name='us-east-1', endpoint_url = context.endpoint_url)
     if token:
         return s3_client.list_objects_v2(
             Bucket=bucket,
